@@ -105,7 +105,7 @@ type PostAnnotation struct {
 	Vms [8]*goluaez.State
 }
 
-// NewAnnotator returns an Annotator with the sources, seeded with some javascript.
+// NewAnnotator returns an Annotator with the sources, seeded with some lua.
 // If ends is true, it will annotate the 1 base ends of the interval as well as the
 // interval itself. If strict is true, when overlapping variants, they must share
 // the ref allele and at least 1 alt allele.
@@ -638,7 +638,7 @@ func (a *Annotator) PostAnnotate(chrom string, start int, end int, info interfac
 				}
 			}
 			// we need to try even if it didn't get all values.
-			if len(vals) == 0 && len(post.Fields) > 0 {
+			if len(vals) == 0 && len(post.Fields) == 0 {
 				continue
 			}
 
